import { ConfigProvider } from 'antd';
import React, { useEffect, useMemo } from 'react';
import Layout from './components/layout.js';
import './css/index.scss';
import 'katex/dist/katex.css';
import '@fortawesome/fontawesome-free/css/all.css';
import { manage } from 'manate';
import { Store } from './store.js';
export const defaultToolbarItems = [
    'about',
    '|',
    'bold',
    'italic',
    'strikethrough',
    'underline',
    'mark',
    '|',
    'emoji',
    'fontawesome',
    '|',
    'quote',
    'unordered-list',
    'ordered-list',
    'unchecked-list',
    'checked-list',
    '|',
    'link',
    'image',
    'code',
    'table',
    '|',
    'math',
    'flowchart',
];
const MarkPlus = (props) => {
    const { markdown, mode, toolbar, theme, toolbarItems } = props;
    const store = useMemo(() => {
        return manage(new Store());
    }, []);
    useEffect(() => {
        store.preferences.mode = mode ?? 'both';
        store.preferences.toolbar = toolbar ?? 'show';
        store.preferences.theme = theme ?? 'auto';
        store.preferences.toolbarItems = toolbarItems ?? defaultToolbarItems;
        store.onChange = props.onChange ?? (() => { });
    }, [mode, toolbar, theme, toolbarItems, store, props.onChange]);
    useEffect(() => {
        store.editor?.dispatch({
            changes: {
                from: 0,
                to: store.editor.state.doc.length,
                insert: markdown ?? '',
            },
        });
    }, [markdown, store.editor]);
    return (React.createElement(ConfigProvider, { theme: {
            token: {
                colorPrimary: '#00b96b',
            },
        } },
        React.createElement(Layout, { store: store })));
};
export default MarkPlus;
